@@ -119,7 +119,7 @@ class Quora:
         want_answers = soup.find('span', attrs={'class' : 'count'}).string
         answer_count = soup.find('div', attrs={'class' : 'answer_count'}).next.split()[0]
         question_text = list(soup.find('div', attrs = {'class' : 'question_text_edit'}).find('h1').children)[-1]
-        question_details = soup.find('div', attrs = {'class' : 'question_details_text'}).string
+        question_details = soup.find('div', attrs = {'class' : 'question_details_text'})
         answer_wiki = soup.find('div', attrs = {'class' : 'AnswerWikiArea'}).find('div')
 
         question_dict = {'want_answers' : try_cast_int(want_answers),
